@@ -22,7 +22,7 @@ You can write your driver with the same interface, but with a different implemen
 
 package WebService::CEPH::NetAmazonS3;
 
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 use strict;
 use warnings;
@@ -99,7 +99,7 @@ Returns buckets list
 sub get_buckets_list {
     my ($self) = @_;
 
-    return $self->{client}->buckets->{buckets};
+    return $self->{client}->buckets;
 }
 
 =head2 upload_single_request
